import javax.swing.*;
import java.awt.*;
import java.awt.geom.Ellipse2D;
import java.util.*;

public class DrawingCruiser {
    private EntityCruiser cruiser; //Класс-сущность
    public EntityCruiser GetCruiser(){return cruiser;}
    public int _startPosX; //Координаты отрисовки по оси x
    public int _startPosY; //Координаты отрисовки по оси y
    private Integer _pictureWidth = null; //Ширина окна
    private Integer _pictureHeight = null; //Высота окна
    private final int _cruiserWidth = 150; //Ширина отрисовки крейсера
    private final int _cruiserHeight = 60; //Высота отрисовки крейсера
    private DrawBlock drawBlock = new DrawBlock();

    //Инициализация
    public void Init(int speed, float weight, Color bodyColor, boolean rocketMines, boolean helipad)
    {
        cruiser = new EntityCruiser();
        cruiser.Init(speed,weight,bodyColor, rocketMines, helipad);
        Random random = new Random();
        drawBlock.SetBlockCount(random.nextInt(1, 4));
    }

    //Начальные коордитанты
    public void SetPosition(int x, int y, int width, int height)
    {
        if (width < _cruiserWidth || height < _cruiserHeight) return;
        Random random = new Random();
        _startPosX = x < 0 || x + _cruiserWidth > width ? random.nextInt(0, width - _cruiserWidth) : x;
        _startPosY = y < 0 || y + _cruiserHeight > height ? random.nextInt(0, height - _cruiserHeight) : y;
        _pictureWidth = width;
        _pictureHeight = height;
    }

    //Движение транспорта по координатам
    public void MoveTransport(Direction direction)
    {
        if (_pictureWidth == null || _pictureHeight == null) return;
        switch (direction)
        {
            case Left: //Влево
                if (_startPosX - cruiser.GetStep() > 0) _startPosX -= cruiser.GetStep();
                break;
            case Up: //Вверх
                if (_startPosY - cruiser.GetStep() > 0) _startPosY -= cruiser.GetStep();
                break;
            case Right: //Вправо
                if (_startPosX + _cruiserWidth + cruiser.GetStep() < _pictureWidth) _startPosX += cruiser.GetStep();
                break;
            case Down: //Вниз
                if (_startPosY + _cruiserHeight + cruiser.GetStep() < _pictureHeight) _startPosY += cruiser.GetStep();
                break;
        }
    }

    //Отрисовка транспорта
    public void DrawTransport(Graphics g)
    {
        if (GetCruiser() == null) return;

        if (_startPosX < 0 || _startPosY < 0 || _pictureWidth == null || _pictureHeight == null)
        {
            return;
        }
        Graphics2D g2d = (Graphics2D) g;
        g2d.setColor(cruiser.GetBodyColor());
        // палуба
        Polygon paluba = new Polygon();
        paluba.addPoint(_startPosX + 10,_startPosY);
        paluba.addPoint(_startPosX + 110,_startPosY);
        paluba.addPoint(_startPosX + 160,_startPosY + 30);
        paluba.addPoint(_startPosX + 110,_startPosY + 60);
        paluba.addPoint(_startPosX + 10,_startPosY + 60);
        g2d.fillPolygon(paluba);
        // элементы
        Polygon elements = new Polygon();
        elements.addPoint(_startPosX + 50,_startPosY + 20);
        elements.addPoint(_startPosX + 70,_startPosY + 20);
        elements.addPoint(_startPosX + 70,_startPosY + 10);
        elements.addPoint(_startPosX + 90,_startPosY + 10);
        elements.addPoint(_startPosX + 90,_startPosY + 50);
        elements.addPoint(_startPosX + 70,_startPosY + 50);
        elements.addPoint(_startPosX + 70,_startPosY + 40);
        elements.addPoint(_startPosX + 50,_startPosY + 40);
        g2d.setColor(Color.BLACK);
        g2d.fillPolygon(elements);
        g2d.fill(new Ellipse2D.Double(_startPosX + 100, _startPosY + 20, 20, 20));

        // турбины
        g2d.setColor(Color.BLACK);
        g2d.fillRect(_startPosX, _startPosY + 10, 10, 20);
        g2d.fillRect(_startPosX, _startPosY + 35, 10, 20);
        // шахты
        if (cruiser.GetRocketMines()) {
            g2d.setColor(Color.green);
            g2d.fillRect(_startPosX + 15, _startPosY + 10, 10, 15);
            g2d.fillRect(_startPosX + 30, _startPosY + 10, 10, 15);
        }
        // верт площадка
        if (cruiser.GetHelipad()) {
            g2d.setColor(Color.ORANGE);
            g2d.fill(new Ellipse2D.Double(_startPosX + 15, _startPosY + 25, 25, 25));
            drawBlock.DrawningBlock(_startPosX, _startPosY, _cruiserWidth, g2d, cruiser.GetBodyColor());
        }
    }
}